import { select, json, tree, hierarchy, transform, zoom, 
        linkHorizontal, linkVertical } from 'd3';


const width=document.body.clientWidth;
const height=document.body.clientHeight;

const treeLayout = data => {
  const root = hierarchy(data);
  root.dx = 10;
  root.dy = width / (root.height + 1);
  return tree().nodeSize([root.dx, root.dy])(root);
};

const svg=select('svg');

svg
  .attr('width', width)
	.attr('height', height)

Promise.all ([
  json('data.json')
]).then(([data]) => {
  //console.log(data);
 const root = treeLayout(data);
 //console.log(root); 
  
  //Establish floor and ceiling
  let x0 = Infinity;
  let x1 = -x0;
  root.each(d => {
    if (d.x > x1) x1 = d.x;
    if (d.x < x0) x0 = d.x;
  });
 
  svg
  	.attr("viewBox", [0, 0, width, x1 - x0 + root.dx * 4]);
  
  const g = svg.append('g')
  	.attr('class', 'canvas')
  	.attr("transform", `translate(${root.dy / 3},${root.dx - x0})`);
  
  svg.call(zoom().on('zoom', ({transform}) => {
    g.attr("transform",transform);
  }));
   
  const links = g.append('g')
    .attr('class', 'links')
  .selectAll('path')
    .data(root.links())
    .join('path')
      .attr("d", linkHorizontal()
          .x(d => d.y)
          .y(d => d.x));
  
  const nodes = g.append('g')
      .attr('class', 'nodes')
    .selectAll("g")
    .data(root.descendants())
    .join('g')
      .attr('transform', d => `translate(${d.y},${d.x})`);
	
  nodes.append('circle') 
  	.attr('class', d => d.children ? 'children' : 'parent')
  	.attr('r', 2.5);
  
  nodes.append("text")
      .attr("dy", "0.31em")
      .attr("x", d => d.children ? -6 : 6)
      .attr("text-anchor", d => d.children ? "end" : "start")
      .text(d => d.data.data.id)
    .clone(true).lower()
      .attr("stroke", "white");
  
  
  
});